; ==================================
; Mazogs Colour Loader for Chroma 81
; ==================================
; (c)2014 Paul Farrow, www.fruitcake.plus.com
;
; Version 1.02, 4th October 2014

; ----------------------------------------------------------------------------------------------------

; ====================
; Assembler Directives
; ====================
; For use with the TASM assembler.

#define END  .END
#define EQU  .EQU
#define DEFB .BYTE
#define DEFW .WORD
#define DEFS .FILL
#define ORG  .ORG
#define DEFM .TEXT

; Assemble using command line arguments: -80 -fFF -g3 -i -s -a

; ----------------------------------------------------------------------------------------------------

; =====================
; Configuration Options
; =====================

; Include to assemble a .P81 file; omit to assemble a .P file.

;#define P81

; ----------------------------------------------------------------------------------------------------

; -----------------
; Attribute Colours
; -----------------
; Bit constants representing the possible components of an attribute byte.
; An attribute value is created by adding together the required constants.

INK_BLACK		EQU	$00
INK_BLUE		EQU	$01
INK_RED			EQU	$02
INK_GREEN		EQU	$04
INK_BRIGHT		EQU	$08
INK_WHITE		EQU	INK_GREEN + INK_RED + INK_BLUE
INK_YELLOW		EQU	INK_GREEN + INK_RED
INK_CYAN		EQU	INK_GREEN + INK_BLUE
INK_MAGENTA		EQU	INK_RED + INK_BLUE

PAPER_BLACK		EQU	$00
PAPER_BLUE		EQU	$10
PAPER_RED		EQU	$20
PAPER_GREEN		EQU	$40
PAPER_BRIGHT		EQU	$80
PAPER_WHITE		EQU	PAPER_GREEN + PAPER_RED + PAPER_BLUE
PAPER_YELLOW		EQU	PAPER_GREEN + PAPER_RED
PAPER_CYAN		EQU	PAPER_GREEN + PAPER_BLUE
PAPER_MAGENTA		EQU	PAPER_RED + PAPER_BLUE

; ----------------------------------------------------------------------------------------------------

; =================================================
; Colour Mapping Table Character Position Constants
; =================================================

_SPACE			EQU	$00
_TOPLEFTBLACK		EQU	$01
_TOPRIGHTBLACK		EQU	$02
_TOPBLACK		EQU	$03
_BOTTOMLEFTBLACK	EQU	$04
_LEFTBLACK		EQU	$05
_BOTTOMLEFTTOPRIGHT	EQU	$06
_BOTTOMRIGHTWHITE	EQU	$07
_LIGHTGREY		EQU	$08
_TOPWHITEBOTTOMGREY	EQU	$09
_TOPGREYBOTTOMWHITE	EQU	$0A
_QUOTE			EQU	$0B
_POUND			EQU	$0C
_DOLLAR			EQU	$0D
_COLON			EQU	$0E
_QUESTIONMARK		EQU	$0F
_OPENBRACKET		EQU	$10
_CLOSEBRACKET		EQU	$11
_GREATERTHAN		EQU	$12
_LESSTHAN		EQU	$13
_EQUALS			EQU	$14
_PLUS			EQU	$15
_MINUS			EQU	$16
_ASTERISK		EQU	$17
_DIVIDE			EQU	$18
_SEMICOLON		EQU	$19
_COMMA			EQU	$1A
_FULLSTOP		EQU	$1B
_0			EQU	$1C
_1			EQU	$1D
_2			EQU	$1E
_3			EQU	$1F
_4			EQU	$20
_5			EQU	$21
_6			EQU	$22
_7			EQU	$23
_8			EQU	$24
_9			EQU	$25
_A			EQU	$26
_B			EQU	$27
_C			EQU	$28
_D			EQU	$29
_E			EQU	$2A
_F			EQU	$2B
_G			EQU	$2C
_H			EQU	$2D
_I			EQU	$2E
_J			EQU	$2F
_K			EQU	$30
_L			EQU	$31
_M			EQU	$32
_N			EQU	$33
_O			EQU	$34
_P			EQU	$35
_Q			EQU	$36
_R			EQU	$37
_S			EQU	$38
_T			EQU	$39
_U			EQU	$3A
_V			EQU	$3B
_W			EQU	$3C
_X			EQU	$3D
_Y			EQU	$3E
_Z			EQU	$3F
_BLACK			EQU	$40
_TOPLEFTWHITE		EQU	$41
_TOPRIGHTWHITE		EQU	$42
_BOTTOMBLACK		EQU	$43
_BOTTOMLEFTWHITE	EQU	$44
_RIGHTBLACK		EQU	$45
_TOPLEFTBOTTOMRIGHT	EQU	$46
_BOTTOMRIGHTBLACK	EQU	$47
_DARKGREY		EQU	$48
_TOPBLACKBOTTOMGREY	EQU	$49
_TOPGREYBOTTOMBLACK	EQU	$4A
_INVQUOTE		EQU	$4B
_INVPOUND		EQU	$4C
_INVDOLLAR		EQU	$4D
_INVCOLON		EQU	$4E
_INVQUESTIONMARK	EQU	$4F
_INVOPENBRACKET		EQU	$50
_INVCLOSEBRACKET	EQU	$51
_INVGREATERTHAN		EQU	$52
_INVLESSTHAN		EQU	$53
_INVEQUALS		EQU	$54
_INVPLUS		EQU	$55
_INVMINUS		EQU	$56
_INVASTERISK		EQU	$57
_INVDIVIDE		EQU	$58
_INVSEMICOLON		EQU	$59
_INVCOMMA		EQU	$5A
_INVFULLSTOP		EQU	$5B
_INV0			EQU	$5C
_INV1			EQU	$5D
_INV2			EQU	$5E
_INV3			EQU	$5F
_INV4			EQU	$60
_INV5			EQU	$61
_INV6			EQU	$62
_INV7			EQU	$63
_INV8			EQU	$64
_INV9			EQU	$65
_INVA			EQU	$66
_INVB			EQU	$67
_INVC			EQU	$68
_INVD			EQU	$69
_INVE			EQU	$6A
_INVF			EQU	$6B
_INVG			EQU	$6C
_INVH			EQU	$6D
_INVI			EQU	$6E
_INVJ			EQU	$6F
_INVK			EQU	$70
_INVL			EQU	$71
_INVM			EQU	$72
_INVN			EQU	$73
_INVO			EQU	$74
_INVP			EQU	$75
_INVQ			EQU	$76
_INVR			EQU	$77
_INVS			EQU	$78
_INVT			EQU	$79
_INVU			EQU	$7A
_INVV			EQU	$7B
_INVW			EQU	$7C
_INVX			EQU	$7D
_INVY			EQU	$7E
_INVZ			EQU	$7F

; ----------------------------------------------------------------------------------------------------

; =======================
; Character Set Constants
; =======================

CHR_SPACE		EQU	$00	; 0
CHR_TOPLEFTBLACK	EQU	$01	; 1
CHR_TOPRIGHTBLACK	EQU	$02	; 2
CHR_TOPBLACK		EQU	$03	; 3
CHR_BOTTOMLEFTBLACK	EQU	$04	; 4
CHR_LEFTBLACK		EQU	$05	; 5
CHR_BOTTOMLEFTTOPRIGHT	EQU	$06	; 6
CHR_BOTTOMRIGHTWHITE	EQU	$07	; 7
CHR_LIGHTGREY		EQU	$08	; 8
CHR_TOPWHITEBOTTOMGREY	EQU	$09	; 9
CHR_TOPGREYBOTTOMWHITE	EQU	$0A	; 10
CHR_QUOTE		EQU	$0B	; 11
CHR_POUND		EQU	$0C	; 12
CHR_DOLLAR		EQU	$0D	; 13
CHR_COLON		EQU	$0E	; 14
CHR_QUESTIONMARK	EQU	$0F	; 15
CHR_OPENBRACKET		EQU	$10	; 16
CHR_CLOSEBRACKET	EQU	$11	; 17
CHR_GREATERTHAN		EQU	$12	; 18
CHR_LESSTHAN		EQU	$13	; 19
CHR_EQUALS		EQU	$14	; 20
CHR_PLUS		EQU	$15	; 21
CHR_MINUS		EQU	$16	; 22
CHR_ASTERISK		EQU	$17	; 23
CHR_DIVIDE		EQU	$18	; 24
CHR_SEMICOLON		EQU	$19	; 25
CHR_COMMA		EQU	$1A	; 26
CHR_FULLSTOP		EQU	$1B	; 27
CHR_0			EQU	$1C	; 28
CHR_1			EQU	$1D	; 29
CHR_2			EQU	$1E	; 30
CHR_3			EQU	$1F	; 31
CHR_4			EQU	$20	; 32
CHR_5			EQU	$21	; 33
CHR_6			EQU	$22	; 34
CHR_7			EQU	$23	; 35
CHR_8			EQU	$24	; 36
CHR_9			EQU	$25	; 37
CHR_A			EQU	$26	; 38
CHR_B			EQU	$27	; 39
CHR_C			EQU	$28	; 40
CHR_D			EQU	$29	; 41
CHR_E			EQU	$2A	; 42
CHR_F			EQU	$2B	; 43
CHR_G			EQU	$2C	; 44
CHR_H			EQU	$2D	; 45
CHR_I			EQU	$2E	; 46
CHR_J			EQU	$2F	; 47
CHR_K			EQU	$30	; 48
CHR_L			EQU	$31	; 49
CHR_M			EQU	$32	; 50
CHR_N			EQU	$33	; 51
CHR_O			EQU	$34	; 52
CHR_P			EQU	$35	; 53
CHR_Q			EQU	$36	; 54
CHR_R			EQU	$37	; 55
CHR_S			EQU	$38	; 56
CHR_T			EQU	$39	; 57
CHR_U			EQU	$3A	; 58
CHR_V			EQU	$3B	; 59
CHR_W			EQU	$3C	; 60
CHR_X			EQU	$3D	; 61
CHR_Y			EQU	$3E	; 62
CHR_Z			EQU	$3F	; 63
CHR_RND			EQU	$40	; 64
CHR_INKEY		EQU	$41	; 65
CHR_PI			EQU	$42	; 66
CHR_CURSORUP		EQU	$70	; 112
CHR_CURSORDOWN		EQU	$71	; 113
CHR_CURSORLEFT		EQU	$72	; 114
CHR_CURSORRIGHT		EQU	$73	; 115
CHR_GRAPHICS		EQU	$74	; 116
CHR_EDIT		EQU	$75	; 117
CHR_NEWLINE		EQU	$76	; 118
CHR_RUBOUT		EQU	$77	; 119
CHR_MODE		EQU	$78	; 120
CHR_FUNCTION		EQU	$79	; 121
CHR_NUMBER		EQU	$7E	; 126
CHR_CURSOR		EQU	$7F	; 127
CHR_BLACK		EQU	$80	; 128
CHR_TOPLEFTWHITE	EQU	$81	; 129
CHR_TOPRIGHTWHITE	EQU	$82	; 130
CHR_BOTTOMBLACK		EQU	$83	; 131
CHR_BOTTOMLEFTWHITE	EQU	$84	; 132
CHR_RIGHTBLACK		EQU	$85	; 133
CHR_TOPLEFTBOTTOMRIGHT	EQU	$86	; 134
CHR_BOTTOMRIGHTBLACK	EQU	$87	; 135
CHR_DARKGREY		EQU	$88	; 136
CHR_TOPBLACKBOTTOMGREY	EQU	$89	; 137
CHR_TOPGREYBOTTOMBLACK	EQU	$8A	; 138
CHR_INVQUOTE		EQU	$8B	; 139
CHR_INVPOUND		EQU	$8C	; 140
CHR_INVDOLLAR		EQU	$8D	; 141
CHR_INVCOLON		EQU	$8E	; 142
CHR_INVQUESTIONMARK	EQU	$8F	; 143
CHR_INVOPENBRACKET	EQU	$90	; 144
CHR_INVCLOSEBRACKET	EQU	$91	; 145
CHR_INVGREATERTHAN	EQU	$92	; 146
CHR_INVLESSTHAN		EQU	$93	; 147
CHR_INVEQUALS		EQU	$94	; 148
CHR_INVPLUS		EQU	$95	; 149
CHR_INVMINUS		EQU	$96	; 150
CHR_INVASTERISK		EQU	$97	; 151
CHR_INVDIVIDE		EQU	$98	; 152
CHR_INVSEMICOLON	EQU	$99	; 153
CHR_INVCOMMA		EQU	$9A	; 154
CHR_INVFULLSTOP		EQU	$9B	; 155
CHR_INV0		EQU	$9C	; 156
CHR_INV1		EQU	$9D	; 157
CHR_INV2		EQU	$9E	; 158
CHR_INV3		EQU	$9F	; 159
CHR_INV4		EQU	$A0	; 160
CHR_INV5		EQU	$A1	; 161
CHR_INV6		EQU	$A2	; 162
CHR_INV7		EQU	$A3	; 163
CHR_INV8		EQU	$A4	; 164
CHR_INV9		EQU	$A5	; 165
CHR_INVA		EQU	$A6	; 166
CHR_INVB		EQU	$A7	; 167
CHR_INVC		EQU	$A8	; 168
CHR_INVD		EQU	$A9	; 169
CHR_INVE		EQU	$AA	; 170
CHR_INVF		EQU	$AB	; 171
CHR_INVG		EQU	$AC	; 172
CHR_INVH		EQU	$AD	; 173
CHR_INVI		EQU	$AE	; 174
CHR_INVJ		EQU	$AF	; 175
CHR_INVK		EQU	$B0	; 176
CHR_INVL		EQU	$B1	; 177
CHR_INVM		EQU	$B2	; 178
CHR_INVN		EQU	$B3	; 179
CHR_INVO		EQU	$B4	; 180
CHR_INVP		EQU	$B5	; 181
CHR_INVQ		EQU	$B6	; 182
CHR_INVR		EQU	$B7	; 183
CHR_INVS		EQU	$B8	; 184
CHR_INVT		EQU	$B9	; 185
CHR_INVU		EQU	$BA	; 186
CHR_INVV		EQU	$BB	; 187
CHR_INVW		EQU	$BC	; 188
CHR_INVX		EQU	$BD	; 189
CHR_INVY		EQU	$BE	; 190
CHR_INVZ		EQU	$BF	; 191
CHR_DOUBLEQUOTE		EQU	$C0	; 192
CHR_AT			EQU	$C1	; 193
CHR_TAB			EQU	$C2	; 194
CHR_CODE		EQU	$C4	; 196
CHR_VAL			EQU	$C5	; 197
CHR_LEN			EQU	$C6	; 198
CHR_SIN			EQU	$C7	; 199
CHR_COS			EQU	$C8	; 200
CHR_TAN			EQU	$C9	; 201
CHR_ASN			EQU	$CA	; 202
CHR_ACS			EQU	$CB	; 203
CHR_ATN			EQU	$CC	; 204
CHR_LN			EQU	$CD	; 205
CHR_EXP			EQU	$CE	; 206
CHR_INT			EQU	$CF	; 207
CHR_SQR			EQU	$D0	; 208
CHR_SGN			EQU	$D1	; 209
CHR_ABS			EQU	$D2	; 210
CHR_PEEK		EQU	$D3	; 211
CHR_USR			EQU	$D4	; 212
CHR_STR			EQU	$D5	; 213
CHR_CHR			EQU	$D6	; 214
CHR_NOT			EQU	$D7	; 215
CHR_DOUBLEASTERISK	EQU	$D8	; 216
CHR_OR			EQU	$D9	; 217
CHR_AND			EQU	$DA	; 218
CHR_LESSTHANEQUAL	EQU	$DB	; 219
CHR_GREATERTHANEQUAL	EQU	$DC	; 220
CHR_NOTEQUAL		EQU	$DD	; 221
CHR_THEN		EQU	$DE	; 222
CHR_TO			EQU	$DF	; 223
CHR_STEP		EQU	$E0	; 224
CHR_LPRINT		EQU	$E1	; 225
CHR_LLIST		EQU	$E2	; 226
CHR_STOP		EQU	$E3	; 227
CHR_SLOW		EQU	$E4	; 228
CHR_FAST		EQU	$E5	; 229
CHR_NEW			EQU	$E6	; 230
CHR_SCROLL		EQU	$E7	; 231
CHR_CONT		EQU	$E8	; 232
CHR_DIM			EQU	$E9	; 233
CHR_REM			EQU	$EA	; 234
CHR_FOR			EQU	$EB	; 235
CHR_GOTO		EQU	$EC	; 236
CHR_GOSUB		EQU	$ED	; 237
CHR_INPUT		EQU	$EE	; 238
CHR_LOAD		EQU	$EF	; 239
CHR_LIST		EQU	$F0	; 240
CHR_LET			EQU	$F1	; 241
CHR_PAUSE		EQU	$F2	; 242
CHR_NEXT		EQU	$F3	; 243
CHR_POKE		EQU	$F4	; 244
CHR_PRINT		EQU	$F5	; 245
CHR_PLOT		EQU	$F6	; 246
CHR_RUN			EQU	$F7	; 247
CHR_SAVE		EQU	$F8	; 248
CHR_RAND		EQU	$F9	; 249
CHR_IF			EQU	$FA	; 250
CHR_CLS			EQU	$FB	; 251
CHR_UNPLOT		EQU	$FC	; 252
CHR_CLEAR		EQU	$FD	; 253
CHR_RETURN		EQU	$FE	; 254
CHR_COPY		EQU	$FF	; 255

; ======================================================================================================================================================

; ========
; Filename
; ========

#ifdef P81

	DEFB _G
	DEFB _A
	DEFB _L
	DEFB _A
	DEFB _X
	DEFB _SPACE
	DEFB _C
	DEFB _O
	DEFB _L
	DEFB _O
	DEFB _U
	DEFB _R + $80

#endif

; ======================================================================================================================================================

; ================
; System Variables
; ================

ERR_NR			EQU  16384		 $4000
FLAGS_SV		EQU  16385		 $4001
ERR_SP			EQU  16386		 $4002
RAMTOP			EQU  16388		 $4004
MODE			EQU  16390		 $4006
PPC			EQU  16391		 $4007

; The ZX81 program is saved from the following location onwards.

	ORG  $4009

VERSN:	DEFB $00	   ; 16393		 $4009
E_PPC:	DEFW 10		   ; 16394		 $400A
D_FILE:	DEFW LB_DFILE	   ; 16396		 $400C
DF_CC:	DEFW LB_DFILE+1	   ; 16398		 $400E
VARS:	DEFW LB_VARS	   ; 16400		 $4010
DEST:	DEFW $00	   ; 16402		 $4012
E_LINE:	DEFW LB_VARS+1	   ; 16404		 $4014
CH_ADD:	DEFW LB_VARS+5	   ; 16406		 $4016
X_PTR:	DEFW $00	   ; 16408		 $4018
STKBOT:	DEFW LB_ELINE+5	   ; 16410		 $401A
STKEND:	DEFW LB_ELINE+5	   ; 16412		 $401C
BERG:	DEFB $00	   ; 16414		 $401E
MEM:	DEFW 16477	   ; 16415		 $401F
SPARE1:	DEFB $00	   ; 16417 - unused	 $4021
DF_SZ:	DEFB $02	   ; 16418		 $4022
S_TOP:	DEFW 10		   ; 16419		 $4023
LAST_K	DEFW 65535	   ; 16421		 $4025
DBOUNC:	DEFB $00	   ; 16423		 $4027
MARGIN:	DEFB 55		   ; 16424		 $4028
NXTLIN:	DEFW LB_BASIC10	   ; 16425		 $4029	Make auto-run from line LB_BASIC10
OLDPPC:	DEFW $00	   ; 16427		 $402B
FLAGX:	DEFB $00	   ; 16429		 $402D
STRLEN:	DEFW $00	   ; 16430		 $402E
T_ADDR: DEFW 3213	   ; 16432		 $4030
SEED:	DEFW $00	   ; 16434		 $4032
FRAMES:	DEFW 59104	   ; 16436		 $4034
COORDS:	DEFW $00	   ; 16438		 $4036
PR_CC:	DEFB 188	   ; 16440		 $4038
S_POSN:	DEFB 33		   ; 16441		 $4039
	DEFB 24		   ; 16442		 $403A
CDFLAG:	DEFB $00	   ; 16443		 $403B	FAST mode
PRBUFF:	DEFW $0000, $0000  ; 16444		 $403C
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFB CHR_NEWLINE   ; 16476		 $405C
MEMBOT:	DEFW $0000, $0000  ; 16477		 $405D
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000, $0000
	DEFW $0000
SPARE2:	DEFB $00	   ; 16507 - unused	 $407B
SPARE3:	DEFB $00	   ; 16508 - unused	 $407C

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; =============
; BASIC Program
; =============

	ORG  $407D			; 16509

LB_BASIC:

; Machine code line 1

	DEFB 0				; Line number 0 (high).
	DEFB 1				; Line number 1 (low).

	DEFW LB_ENDLINE01-LB_TOKEN01+1	; Length of REM contents including trailing newline character.

LB_TOKEN01:
	DEFB CHR_REM

LB_HIDE:
	DEFB CHR_NEWLINE		; Hide the rest of the line.
	DEFB CHR_NEWLINE

; ------------------------------------------------------------------------------------------------------------------------------------------------------


; Default all characters to black ink on bright white paper

	LD   BC,$7FEF		; Chroma colour input port.
	IN   A,(C)
	BIT  5,A		; Are the colour facilities enabled?
	JR   Z,COLOUR_PRESENT	; Jump ahead if they are.

	LD   BC,$0001		; Signal that the colour facilities are not available.
	RET

COLOUR_PRESENT:	
	LD   HL,$C000		; Default all characters to black ink on bright white paper.
	LD   DE,$C001
	LD   BC,$03FF		; 128 characters consisting of 8 pixel lines.
	LD   (HL),PAPER_BLACK + INK_CYAN + INK_BRIGHT
	LDIR

	LD   DE,MAPPING_TABLE	; Point to the table defining the colour mappings to configure.

CHAR_NEXT:
	LD   A,(DE)		; Fetch the initial character to colour.
	CP   $FF		; Has the end of the table been reached?
	JR   Z,CHARS_COPIED	; Jump ahead if it has.

	LD   H,$00		; Multiply the character position by 8 (since the mapping table defines colours for each pixel line).
	LD   L,A
	AND  A
	RL   L
	RL   H
	RL   L
	RL   H
	RL   L
	RL   H
	LD   A,$C0		; The base address high byte.
	ADD  A,H
	LD   H,A		; HL=Address within the colour mapping table.

	INC  DE			; Advance to the character count field.
	LD   A,(DE)		; Fetch the character count.
	LD   B,A

	INC  DE			; Advance to the colour definition for the first pixel line.
	EX   DE,HL

CHAR_LOOP:
	PUSH BC
	PUSH HL

	LD   BC,$0008		; Copy the 8 pixel line colour definitions into the colour mapping table.
	LDIR

	POP  HL
	POP  BC
	DJNZ CHAR_LOOP		; Repeat for all 8 pixel lines.

	EX   DE,HL

	INC  DE			; Advance to the next table entry.
	INC  DE
	INC  DE
	INC  DE
	INC  DE
	INC  DE
	INC  DE
	INC  DE
	JR   CHAR_NEXT		; Loop back to process the next table entry.

; All colour mapping entries have been set up.

CHARS_COPIED:
	LD   A,$20		; Colour mode 0 and enabled colour mode.
	LD   BC,$7FEF		; Chroma colour IO control port.
	OUT  (C),A		; Select the colour mode.

	LD   BC,$0000		; Signal that the colour facilities are available.
	RET

; ---------------
; Colour Mappings
; ---------------
; Each entry consists of fields specifying:
; - Start character position in the colour mapping table to configure
; - Number of characters to colour
; - Colours for each of the 8 pixel lines

MAPPING_TABLE:
	DEFB _TOPLEFTBLACK
	DEFB $07
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT


	DEFB _TOPLEFTWHITE
	DEFB $07
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT
	DEFB 	INK_GREEN + INK_BRIGHT


	DEFB _0
	DEFB $0A
	DEFB 	INK_YELLOW + INK_BRIGHT
	DEFB 	INK_YELLOW + INK_BRIGHT
	DEFB 	INK_YELLOW + INK_BRIGHT
	DEFB 	INK_YELLOW + INK_BRIGHT
	DEFB 	INK_YELLOW + INK_BRIGHT
	DEFB 	INK_YELLOW + INK_BRIGHT
	DEFB 	INK_YELLOW + INK_BRIGHT
	DEFB 	INK_YELLOW + INK_BRIGHT


	DEFB _LIGHTGREY
	DEFB $01
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT


	DEFB _TOPWHITEBOTTOMGREY
	DEFB $04
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT


	DEFB _OPENBRACKET
	DEFB $04
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT


	DEFB _DOLLAR
	DEFB $01
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT


	DEFB _EQUALS
	DEFB $01
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT
	DEFB INK_BLUE + INK_BRIGHT


	DEFB _PLUS
	DEFB $01
	DEFB INK_YELLOW + INK_BRIGHT
	DEFB INK_YELLOW + INK_BRIGHT
	DEFB INK_YELLOW + INK_BRIGHT
	DEFB INK_YELLOW + INK_BRIGHT
	DEFB INK_YELLOW + INK_BRIGHT
	DEFB INK_YELLOW + INK_BRIGHT
	DEFB INK_YELLOW + INK_BRIGHT
	DEFB INK_YELLOW + INK_BRIGHT


	DEFB _MINUS
	DEFB $01
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT
	DEFB INK_RED + INK_BRIGHT


	DEFB _ASTERISK
	DEFB $01
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT
	DEFB INK_CYAN + INK_BRIGHT


	DEFB $FF			; End of table 



; ----------------------------------------------------------------------------------------------------

LB_ENDLINE01:
	DEFB CHR_NEWLINE

; -------- LINE 10 --------

LB_BASIC10:
	DEFB 0				; Line number 0 (high).
	DEFB 10				; Line number 10 (low).

	DEFW LB_ENDLINE10-LB_TOKEN10+1	; Length of REM contents including trailing newline character.

LB_TOKEN10:
	DEFB CHR_RAND			; 10 RAND USR VAL "16516"
	DEFB CHR_USR
	DEFB CHR_VAL
	DEFB CHR_QUOTE
	DEFB CHR_1
	DEFB CHR_6
	DEFB CHR_5
	DEFB CHR_1
	DEFB CHR_6
	DEFB CHR_QUOTE

LB_ENDLINE10:
	DEFB CHR_NEWLINE

; -------- LINE 20 --------

LB_BASIC20:
	DEFB 0				; Line number 0 (high).
	DEFB 20				; Line number 20 (low).

	DEFW LB_ENDLINE20-LB_TOKEN20+1	; Length of REM contents including trailing newline character.

LB_TOKEN20:
	DEFB CHR_LOAD			; 20 LOAD "HR-GALAX"
	DEFB CHR_QUOTE
	DEFB CHR_H
	DEFB CHR_R
	DEFB CHR_MINUS
	DEFB CHR_G
	DEFB CHR_A
	DEFB CHR_L
	DEFB CHR_A
	DEFB CHR_X
	DEFB CHR_QUOTE

LB_ENDLINE20:
	DEFB CHR_NEWLINE

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; ============
; Display File
; ============

LB_DFILE:
	DEFB CHR_NEWLINE
DF_ROW1:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW2:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW3:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW4:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW5:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW6:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW7:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW8:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW9:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW10:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW11:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW12:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW13:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW14:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW15:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW16:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW17:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW18:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW19:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW20:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW21:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW22:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW23:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE
DF_ROW24:
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00, $00
	DEFB CHR_NEWLINE

; ------------------------------------------------------------------------------------------------------------------------------------------------------

; ==============
; Variables Area
; ==============

LB_VARS:
	DEFB $80		; End of variables area marker.

; This is the last location saved in the ZX81 program.

; ======================================================================================================================================================

; =================
; Editing Workspace
; =================

LB_ELINE:

; ------------------------------------------------------------------------------------------------------------------------------------------------------

	END



